==> phpAdsNew-1.9.0.tar.gz: phpAdsNew_1.9.0/language/french.inc.php <==
<?

$strHome = "Accueil";
$date_format = "%d/%m/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "Erreur MySQL:";
$strAdminstration = "Administration";
$strAddClient = "Ajouter nouveau client";
$strModifyClient = "Modifier client";
$strDeleteClient = "Supprimer client";
$strViewClientStats = "Voir les statistiques du client";
$strClientName = "Client";
$strContact = "Contact";
$strEMail = "EMail";
$strViews = "Affichages";
$strClicks = "Clics";
$strTotalViews = "Total des affichages";
$strTotalClicks = "Total des clics";
$strCTR = "Pourcentage de clics";
$strTotalClients = "Total clients";
$strActiveClients = "Clients actifs";
$strActiveBanners = "Bandeaux actifs";
$strLogout = "Se dconnecter";
$strCreditStats = "Statistiques des crdits";
$strViewCredits = "Crdits d'affichages";
$strClickCredits = "Crdits de clics";
$strPrevious = "Prcdent";
$strNext = "Suivant";
$strNone = "Aucun";
$strViewsPurchased = "Affichages achets";
$strClicksPurchased = "Clics achets";
$strDaysPurchased = "Jours d'affichage achets";
$strHTML = "HTML";
$strAddSep = "Remplissez SOIT les champs ci-dessus SOIT ceux ci-dessous !";
$strTextBelow = "Texte sous le bandeau";
$strSubmit = "Soumettre la publicit";
$strUsername = "Nom d'utilisateur";
$strPassword = "Mot de passe";
$strBannerAdmin = "Administration de bandeaux pour";
$strBannerAdminAcl = "Administration des contrles d'accs pour";
$strNoBanners = "Pas de bandeaux trouvs";
$strBanner = "Bandeau";
$strCurrentBanner = "Bandeau courant";
$strDelete = "Supprimer";
$strAddBanner  = "Ajouter nouveau bandeau";
$strModifyBanner  = "Modifier bandeau";
$strModifyBannerAcl  = "Modifier les contrles d'accs du bandeau";
$strURL = "Li  l'URL (avec http://)";
$strKeyword = "Mot cl";
$strWeight = "Poids";
$strAlt = "Alt-Texte";
$strUsername = "Nom d'utilisateur";
$strPassword = "Mot de passe";
$strAccessDenied = "Accs interdit";
$strNotAdmin = "Vous n'avez pas les droits d'administration";
$strClientAdded = "La client a t ajout.";
$strClientModified = "Le client a t modifi.";
$strClientDeleted = "Le client a t supprim.";
$strBannerAdmin = "Administration de bandeaux";
$strBannerAdded = "La bandeau a t ajout.";
$strBannerModified = "Le bandeau a t modifi.";
$strBannerDeleted = "Le bandeau a t supprim.";
$strBannerChanged = "Le bandeau a t chang.";
$strStats = "Statistiques";
$strDailyStats = "Statistiques journalires";
$strDetailStats = "Statistiques dtailles";
$strCreditStats = "Statistiques des crdits";
$strActive = "actif";
$strActivate = "Activer";
$strDeActivate = "Dsactiver";
$strAuthentification = "Authentification";
$strGo = "Aller";
$strLinkedTo = "li ";
$strBannerID = "Bandeau ID";
$strClientID = "Client ID";
$strMailSubject = "Bilan publicitaire";
$strMailSubjectDeleted = "Publicits dsactives";
$strMailHeader = 'Cher ".$clients[$i]["contact"].",\n';
$strMailBannerStats = 'ci-dessous vous trouverez les statistiques des bandeaux pour ".$clients[$i]["clientname"].":';
$strMailFooter = 'Cordialement,\n   $phpAds_admin_fullname';
$strMailNothingLeft = "vous n'avez plus d'affichages sur votre compte chez nous. En consquence, vos bandeaux ont t dsactivs.\n\nSi vous voulez achetez des affichages supplmentaires, prire de nous contacter. Nous serons heureux d'avoir de vos nouvelles.";
$strLogMailSent = "[phpAds] Statistiques envoyes avec succs.";
$strLogErrorClients = "[phpAds] Une erreur a eue lieue en tentant de rcuprer les clients de la base de donnes.";
$strLogErrorBanners = "[phpAds] Une erreur a eue lieue en tentant de rcuprer les bandeaux de la base de donnes.";
$strLogErrorViews = "[phpAds] Une erreur a eue lieue en tentant de rcuprer les affichages de la base de donnes.";
$strLogErrorClicks = "[phpAds] Une erreur a eue lieue en tentant de rcuprer les affichages/clics de la base de donnes.";
$strLogErrorDisactivate = "[phpAds] Une erreur a eue lieue en tentant de dsactiver un bandeau.";
$strRatio = "Pourcentage de clics";
$strChooseBanner = "Veuillez choisir le type de bandeau.";
$strMySQLBanner = "Bandeau stock dans MySQL";
$strURLBanner = "Bandeau rcupr par une URL";
$strHTMLBanner = "Bandeau HTML";
$strNewBannerFile = "Fichier du bandeau";
$strNewBannerURL = "URL du bandeau (avec http://)";
$strWidth = "Largeur";
$strHeight = "Hauteur";
$strTotalViews7Days = "Total des affichages dans les 7 derniers jours";
$strTotalClicks7Days = "Total des clics dans les 7 derniers jours";
$strAvgViews7Days = "Nombre moyen d'affichages dans les 7 derniers jours";
$strAvgClicks7Days = "Nombre moyen de clics dans les 7 derniers jours";
$strTopTenHosts = "Top 10 des machines clientes";
$strConfirmDeleteClient = "Est-ce que vous voulez vraiment supprimer ce client ?";
$strClientIP = "IP du client";
$strUserAgent = "Expression rationnelle du navigateur";
$strWeekDay = "Journe de la semaine (0 - 6)";
$strDomain = "Domaine (sans le point)";
$strSource = "Source";
$strTime = "Horaire";
$strAllow = "Permettre";
$strDeny = "Refuser";
$strResetStats = "Rinitialise les statistiques";
$strConfirmResetStats = "Do you really want to reset stats for this client ?";
$strExpiration = "Expiration";
$strDaysLeft = "Days left";
$strEstimated = "Estimated expiration";
$strConfirm = "Are you sure ?";
$strBannerNoStats = "No statistics available for this banner!";
$strWeek = "Semaine";
$strWeeklyStats = "Weekly statistics";
$strWeekDay = "Weekday";
$strDate = "Date";
$strCTRShort = "CTR";
$strDayShortCuts=array("Su","Mo","Tu","We","Th","Fr","Sa");
$strShowWeeks="Max. weeks to display";
$strAll="all";
$strAvg="Avg.";
$strHourly="Views/Clicks by hour";
$strTotal = "Total";
$strUnlimited = "Unlimited";
$strSave="Save";
$strUp = "Up";
$strDown = "Down";
$strSaved="was saved!";
$strDeleted = "was deleted!";  
$strMovedUp = "was moved up";
$strMovedDown = "was moved down";
$strUpdated = "was updated";
$strACL = "ACL";
$strNoMoveUp = "Can't move up first row";
$strACLAdd = "Add new $strACL";
$strACLExist = "Existing $strACL:";
$strLogin = "Login";

$strTrackerImage = "Tracker image:";
?>

==> phpAdsNew-1.9.2.tar.gz: phpAdsNew_1.9.2/language/french.inc.php <==
<?

$strHome = "Accueil";
$date_format = "%d/%m/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "Erreur MySQL:";
$strAdminstration = "Administration";
$strAddClient = "Ajouter nouveau client";
$strModifyClient = "Modifier client";
$strDeleteClient = "Supprimer client";
$strViewClientStats = "Voir les statistiques du client";
$strClientName = "Client";
$strContact = "Contact";
$strEMail = "EMail";
$strViews = "Affichages";
$strClicks = "Clics";
$strTotalViews = "Total des affichages";
$strTotalClicks = "Total des clics";
$strCTR = "Pourcentage de clics";
$strTotalClients = "Total clients";
$strActiveClients = "Clients actifs";
$strActiveBanners = "Bandeaux actifs";
$strLogout = "Se dconnecter";
$strCreditStats = "Statistiques des crdits";
$strViewCredits = "Crdits d'affichages";
$strClickCredits = "Crdits de clics";
$strPrevious = "Prcdent";
$strNext = "Suivant";
$strNone = "Aucun";
$strViewsPurchased = "Affichages achets";
$strClicksPurchased = "Clics achets";
$strDaysPurchased = "Jours d'affichage achets";
$strHTML = "HTML";
$strAddSep = "Remplissez SOIT les champs ci-dessus SOIT ceux ci-dessous !";
$strTextBelow = "Texte sous le bandeau";
$strSubmit = "Soumettre la publicit";
$strUsername = "Nom d'utilisateur";
$strPassword = "Mot de passe";
$strBannerAdmin = "Administration de bandeaux pour";
$strBannerAdminAcl = "Administration des contrles d'accs pour";
$strNoBanners = "Pas de bandeaux trouvs";
$strBanner = "Bandeau";
$strCurrentBanner = "Bandeau courant";
$strDelete = "Supprimer";
$strAddBanner  = "Ajouter nouveau bandeau";
$strModifyBanner  = "Modifier bandeau";
$strModifyBannerAcl  = "Modifier les contrles d'accs du bandeau";
$strURL = "Li  l'URL (avec http://)";
$strKeyword = "Mot cl";
$strWeight = "Poids";
$strAlt = "Alt-Texte";
$strUsername = "Nom d'utilisateur";
$strPassword = "Mot de passe";
$strAccessDenied = "Accs interdit";
$strNotAdmin = "Vous n'avez pas les droits d'administration";
$strClientAdded = "La client a t ajout.";
$strClientModified = "Le client a t modifi.";
$strClientDeleted = "Le client a t supprim.";
$strBannerAdmin = "Administration de bandeaux";
$strBannerAdded = "La bandeau a t ajout.";
$strBannerModified = "Le bandeau a t modifi.";
$strBannerDeleted = "Le bandeau a t supprim.";
$strBannerChanged = "Le bandeau a t chang.";
$strStats = "Statistiques";
$strDailyStats = "Statistiques journalires";
$strDetailStats = "Statistiques dtailles";
$strCreditStats = "Statistiques des crdits";
$strActive = "actif";
$strActivate = "Activer";
$strDeActivate = "Dsactiver";
$strAuthentification = "Authentification";
$strGo = "Aller";
$strLinkedTo = "li ";
$strBannerID = "Bandeau ID";
$strClientID = "Client ID";
$strMailSubject = "Bilan publicitaire";
$strMailSubjectDeleted = "Publicits dsactives";
$strMailHeader = 'Cher ".$clients[$i]["contact"].",\n';
$strMailBannerStats = 'ci-dessous vous trouverez les statistiques des bandeaux pour ".$clients[$i]["clientname"].":';
$strMailFooter = 'Cordialement,\n   $phpAds_admin_fullname';
$strMailNothingLeft = "vous n'avez plus d'affichages sur votre compte chez nous. En consquence, vos bandeaux ont t dsactivs.\n\nSi vous voulez achetez des affichages supplmentaires, prire de nous contacter. Nous serons heureux d'avoir de vos nouvelles.";
$strLogMailSent = "[phpAds] Statistiques envoyes avec succs.";
$strLogErrorClients = "[phpAds] Une erreur a eue lieue en tentant de rcuprer les clients de la base de donnes.";
$strLogErrorBanners = "[phpAds] Une erreur a eue lieue en tentant de rcuprer les bandeaux de la base de donnes.";
$strLogErrorViews = "[phpAds] Une erreur a eue lieue en tentant de rcuprer les affichages de la base de donnes.";
$strLogErrorClicks = "[phpAds] Une erreur a eue lieue en tentant de rcuprer les affichages/clics de la base de donnes.";
$strLogErrorDisactivate = "[phpAds] Une erreur a eue lieue en tentant de dsactiver un bandeau.";
$strRatio = "Pourcentage de clics";
$strChooseBanner = "Veuillez choisir le type de bandeau.";
$strMySQLBanner = "Bandeau stock dans MySQL";
$strURLBanner = "Bandeau rcupr par une URL";
$strHTMLBanner = "Bandeau HTML";
$strNewBannerFile = "Fichier du bandeau";
$strNewBannerURL = "URL du bandeau (avec http://)";
$strWidth = "Largeur";
$strHeight = "Hauteur";
$strTotalViews7Days = "Total des affichages dans les 7 derniers jours";
$strTotalClicks7Days = "Total des clics dans les 7 derniers jours";
$strAvgViews7Days = "Nombre moyen d'affichages dans les 7 derniers jours";
$strAvgClicks7Days = "Nombre moyen de clics dans les 7 derniers jours";
$strTopTenHosts = "Top 10 des machines clientes";
$strConfirmDeleteClient = "Est-ce que vous voulez vraiment supprimer ce client ?";
$strClientIP = "IP du client";
$strUserAgent = "Expression rationnelle du navigateur";
$strWeekDay = "Journe de la semaine (0 - 6)";
$strDomain = "Domaine (sans le point)";
$strSource = "Source";
$strTime = "Horaire";
$strAllow = "Permettre";
$strDeny = "Refuser";
$strResetStats = "Rinitialise les statistiques";
$strConfirmResetStats = "Voulez vous reellement reinitialiser les stats de ce client ?";
$strExpiration = "Expiration";
$strDaysLeft = "Jours restants";
$strEstimated = "Expiration estimee";
$strConfirm = "Etes vous sur ?";
$strBannerNoStats = "Pas de statistique pour cette banniere!";
$strWeek = "Semaine";
$strWeeklyStats = "Statistiques hebdomadaires";
$strWeekDay = "Jour de la semaine";
$strDate = "Date";
$strCTRShort = "CTR";
$strDayShortCuts=array("Di","Lu","Ma","Me","Je","Ve","Sa");
$strShowWeeks="Nb max. de semaines a afficher";
$strAll="tout";
$strAvg="Moy.";
$strHourly="Vues/Clics par heure";
$strTotal = "Total";
$strUnlimited = "Illimite";
$strSave="Sauve";
$strUp = "Haut";
$strDown = "Bas";
$strSaved="sauve!";
$strDeleted = "efface!";  
$strMovedUp = "remonte!";
$strMovedDown = "descendu";
$strUpdated = "mis a jour";
$strACL = "ACL";
$strNoMoveUp = "ne pas monter la premiere ligne";
$strACLAdd = "Ajouter nouveau $strACL";
$strACLExist = "$strACL existant:";
$strLogin = "Login";

$strTrackerImage = "Tracker image:";
?>
